@@ -160,6 +160,7 @@ def test_mock_patch_dict_resetall(mocker: MockerFixture) -> None:
         "MagicMock",
         "Mock",
         "mock_open",
+        "NonCallableMagicMock",
         "NonCallableMock",
         "PropertyMock",
         "sentinel",
@@ -884,7 +885,7 @@ def test_warn_patch_object_context_manager(mocker: MockerFixture) -> None:
         "Mocks returned by pytest-mock do not need to be used as context managers. "
         "The mocker fixture automatically undoes mocking at the end of a test. "
         "This warning can be ignored if it was triggered by mocking a context manager. "
-        "https://github.com/pytest-dev/pytest-mock#note-about-usage-as-context-manager"
+        "https://pytest-mock.readthedocs.io/en/latest/remarks.html#usage-as-context-manager"
     )
 
     with pytest.warns(
@@ -901,7 +902,7 @@ def test_warn_patch_context_manager(mocker: MockerFixture) -> None:
         "Mocks returned by pytest-mock do not need to be used as context managers. "
         "The mocker fixture automatically undoes mocking at the end of a test. "
         "This warning can be ignored if it was triggered by mocking a context manager. "
-        "https://github.com/pytest-dev/pytest-mock#note-about-usage-as-context-manager"
+        "https://pytest-mock.readthedocs.io/en/latest/remarks.html#usage-as-context-manager"
     )
 
     with pytest.warns(
